@@ -1,18 +1,18 @@
 # vim: ai et sw=4
-# ABSTRACT: YAML Configuration Plugin for Mojolicious
 use strict;
 use warnings;
 package Mojolicious::Plugin::YamlConfig;
 
-use YAML::XS();
 use base 'Mojolicious::Plugin::JsonConfig';
 
-our $VERSION = '0.0.3';
+our $VERSION = '0.0.4';
 
 sub register {
    my ($self, $app, $conf) = @_;
    $conf ||= {};
-   $conf->{ext} ||= 'yaml';
+   $conf->{ext} = 'yaml';
+   $conf->{class} ||= 'YAML::Tiny';
+   $self->{class} = $conf->{class};
    return $self->SUPER::register($app, $conf);
 }
 
@@ -20,11 +20,14 @@ sub _parse_config {
     my ($self, $encoded, $name) = @_;
     local $@;
 
+    my $class = $self->{class};
+    eval "require $class; 1" || die($@);
+
     # Parse
     my ($config,$error);
-    eval {
-        $config = YAML::XS::Load($encoded);
-    }; if($@) {
+
+    $config = eval $class.'::Load($encoded)';
+    if($@) {
         $error = $@;
     }
 
@@ -59,9 +62,10 @@ Mojolicious::Plugin::YamlConfig - YAML Configuration Plugin
     my $config = $self->stash('config');
 
     # Everything can be customized with options
-    my $config = plugin yaml_config => {
+    plugin yaml_config => {
         file      => '/etc/myapp.conf',
-        stash_key => 'conf'
+        stash_key => 'conf',
+        class     => 'YAML::XS'
     };
 
 =head2 DESCRIPTION
@@ -69,6 +73,13 @@ Mojolicious::Plugin::YamlConfig - YAML Configuration Plugin
 Look at L<Mojolicious::Plugin::JsonConfig> and replace "json" with "yaml"
 and you should be fine. :)
 
+=head2 LIMITATIONS
+
+L<YAML::Tiny> is the default parser. It doesn't even try to implement the full
+YAML spec. Currently you can use YAML::XS via the C<class> option to parse the
+data with L<YAML::XS> (It's currently the only supported alternative. Use
+L<YAML>, L<YAML::Any>, L<YAML::Old> or L<YAML::Syck> at your own risk).
+
 =head2 AUTHOR
 
 Danijel Tasov <data@cpan.org>
